@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "18.0.1.1";
+        "18.0.2";
 
     private static final String java_version_date =
-        "2022-04-22";
+        "2022-07-19";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,16 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "18.0.1.1+2";
+        "18.0.2+0";
 
     private static final String VERSION_NUMBER =
-        "18.0.1.1";
+        "18.0.2";
 
     private static final String VERSION_SPECIFICATION =
         "18";
 
     private static final String VERSION_BUILD =
-        "2";
+        "0";
 
     private static final String VERSION_PRE =
         "";
