@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -157,13 +153,37 @@ public class FormatData_ca extends ListResourceBundle {
         final String[] metaValue_AmPmMarkers = new String[] {
                "a.\u00a0m.",
                "p.\u00a0m.",
+               "mitjanit",
+               "",
+               "matinada",
+               "mat\u00ed",
+               "migdia",
+               "tarda",
+               "vespre",
+               "",
+               "nit",
+               "",
+            };
+        final String[] metaValue_narrow_AmPmMarkers = new String[] {
+               "a.\u00a0m.",
+               "p.\u00a0m.",
+               "mitjanit",
+               "",
+               "mat.",
+               "mat\u00ed",
+               "md",
+               "tarda",
+               "vespre",
+               "",
+               "nit",
+               "",
             };
         final String[] metaValue_Eras = new String[] {
                "aC",
                "dC",
             };
         final String[] metaValue_TimePatterns = new String[] {
-               "H:mm:ss zzzz",
+               "H:mm:ss (zzzz)",
                "H:mm:ss z",
                "H:mm:ss",
                "H:mm",
@@ -207,7 +227,7 @@ public class FormatData_ca extends ListResourceBundle {
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "calendari civil isl\u00e0mic" },
-            { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -224,18 +244,19 @@ public class FormatData_ca extends ListResourceBundle {
                     "despr\u00e9s de Crist",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "DateTimePatterns",
                 new String[] {
-                    "{1} 'a' 'les' {0}",
-                    "{1} 'a' 'les' {0}",
+                    "{1}, 'a' 'les' {0}",
+                    "{1}, 'a' 'les' {0}",
                     "{1}, {0}",
                     "{1} {0}",
                 }
             },
-            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -249,6 +270,8 @@ public class FormatData_ca extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -259,6 +282,7 @@ public class FormatData_ca extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "a.\u00a0m./p.\u00a0m." },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "calendari de la Rep\u00fablica de Xina" },
             { "islamic.DatePatterns", metaValue_japanese_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -266,13 +290,6 @@ public class FormatData_ca extends ListResourceBundle {
             { "field.second", "segon" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns",
                 new String[] {
                     "EEEE d MMMM 'de' y GGGG",
@@ -283,7 +300,8 @@ public class FormatData_ca extends ListResourceBundle {
             },
             { "calendarname.islamic", "calendari isl\u00e0mic" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "DayPeriodRules", "midnight:00:00;night1:21:00-24:00;morning2:06:00-12:00;afternoon1:12:00-13:00;morning1:00:00-06:00;afternoon2:13:00-19:00;evening1:19:00-21:00" },
+            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations",
                 new String[] {
@@ -308,21 +326,21 @@ public class FormatData_ca extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 miler",
-                    "00 milers",
-                    "000 milers",
-                    "0 mili\u00f3",
-                    "00 milions",
-                    "000 milions",
-                    "0 miler de milions",
-                    "00 milers de milions",
-                    "000 milers de milions",
-                    "0 bili\u00f3",
-                    "00 bilions",
-                    "000 bilions",
+                    "{one:0' 'miler other:0' 'milers}",
+                    "{one:00' 'milers other:00' 'milers}",
+                    "{one:000' 'milers other:000' 'milers}",
+                    "{one:0' 'mili\u00f3 other:0' 'milions}",
+                    "{one:00' 'milions other:00' 'milions}",
+                    "{one:000' 'milions other:000' 'milions}",
+                    "{one:0' 'miler' 'de' 'milions other:0' 'milers' 'de' 'milions}",
+                    "{one:00' 'milers' 'de' 'milions other:00' 'milers' 'de' 'milions}",
+                    "{one:000' 'milers' 'de' 'milions other:000' 'milers' 'de' 'milions}",
+                    "{one:0' 'bili\u00f3 other:0' 'bilions}",
+                    "{one:00' 'bilions other:00' 'bilions}",
+                    "{one:000' 'bilions other:000' 'bilions}",
                 }
             },
-            { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
@@ -336,7 +354,7 @@ public class FormatData_ca extends ListResourceBundle {
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "fus horari" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
@@ -397,18 +415,18 @@ public class FormatData_ca extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0m",
-                    "00m",
-                    "000m",
-                    "0\u00a0M",
-                    "00\u00a0M",
-                    "000\u00a0M",
-                    "0000\u00a0M",
-                    "00mM",
-                    "000mM",
-                    "0\u00a0B",
-                    "00\u00a0B",
-                    "000\u00a0B",
+                    "{one:0m other:0m}",
+                    "{one:00m other:00m}",
+                    "{one:000m other:000m}",
+                    "{one:0\u00a0M other:0\u00a0M}",
+                    "{one:00\u00a0M other:00\u00a0M}",
+                    "{one:000\u00a0M other:000\u00a0M}",
+                    "{one:0000\u00a0M other:0000\u00a0M}",
+                    "{one:00mM other:00mM}",
+                    "{one:000mM other:000mM}",
+                    "{one:0\u00a0B other:0\u00a0B}",
+                    "{one:00\u00a0B other:00\u00a0B}",
+                    "{one:000\u00a0B other:000\u00a0B}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -426,6 +444,7 @@ public class FormatData_ca extends ListResourceBundle {
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
+            { "PluralRules", "one:i = 1 and v = 0" },
             { "field.hour", "hora" },
             { "calendarname.buddhist", "calendari budista" },
             { "standalone.MonthNames",
@@ -445,6 +464,14 @@ public class FormatData_ca extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
